@@ -19,12 +19,20 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ChecksumAggregationMethodType", "ChecksumAlgorithmType", "StatusType", "ServiceName")
+__all__ = (
+    "ChecksumAggregationMethodType",
+    "ChecksumAlgorithmType",
+    "StatusType",
+    "EBSServiceName",
+    "ServiceName",
+    "ResourceServiceName",
+)
 
 
 ChecksumAggregationMethodType = Literal["LINEAR"]
 ChecksumAlgorithmType = Literal["SHA256"]
 StatusType = Literal["completed", "error", "pending"]
+EBSServiceName = Literal["ebs"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -56,6 +64,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -178,6 +187,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -326,3 +336,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
